@@ -1,4 +1,4 @@
-context("check_sim")
+
 
 set.seed(123)
 n <- 20
@@ -8,10 +8,10 @@ B <- igraph::induced_subgraph(cgnp_pair$graph2, 1:10)
 
 sim_rect <- matrix(runif(10 * n), n)
 sim_sq <- pad(sim_rect, 0, n - 10)
-graph_match_FW(A, B, start = "bari", sim = sim_rect)
-graph_match_FW(A, B, start = "bari", sim = sim_sq)
-graph_match_FW(A, B, start = "bari", seeds = 1:3, sim = sim_sq)
-graph_match_FW(A, B, start = "bari", sim = NULL)
+gm(A, B, start = "bari", sim = sim_rect, method = "indefinite")
+gm(A, B, start = "bari", sim = sim_sq, method = "indefinite")
+gm(A, B, start = "bari", seeds = 1:3, sim = sim_sq, method = "indefinite")
+gm(A, B, start = "bari", sim = NULL, method = "indefinite")
 
 
 test_that(
@@ -19,7 +19,7 @@ test_that(
   {
     expect_error({
       sim_bad <- matrix(runif(10 * n - 10), n - 10)
-      graph_match_FW(A, B, start = "bari", sim = sim_bad)
+      gm(A, B, start = "bari", sim = sim_bad, method = "indefinite")
     },
     "Non square similarity matrices.*")
   }
@@ -31,8 +31,8 @@ test_that(
   {
     expect_error({
       sim_bad <- matrix(runif(10 * 10), 10)
-      graph_match_FW(A, B, start = "bari", sim = sim_bad)
+      gm(A, B, start = "bari", sim = sim_bad, method = "indefinite")
     },
     "Square similarity matrices.*")
   }
-)
\ No newline at end of file
+)
